#
# spec file for package discover
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           discover
Version:        5.18.5
Release:        bp153.1.36
Summary:        Software store for the KDE Plasma desktop
License:        GPL-2.0-only AND GPL-3.0-only AND GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            https://quickgit.kde.org/?p=discover.git
Source:         https://download.kde.org/stable/plasma/%{version}/discover-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/plasma/%{version}/discover-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch1:         0001-Warning-for-FlatHub.patch
BuildRequires:  cmake >= 2.8.12
BuildRequires:  extra-cmake-modules
BuildRequires:  flatpak-devel
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(AppStreamQt) >= 0.11.1
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Attica)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KUserFeedback)
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(packagekitqt5) >= 1.0.1
BuildRequires:  pkgconfig(fwupd) >= 1.0.6
Requires:       kdeclarative-components
Requires:       kirigami2
Requires:       kuserfeedback-imports
Requires:       libqt5-qtquickcontrols2
Recommends:     %{name}-lang
Recommends:     %{name}-backend-packagekit
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150100
Recommends:     %{name}-backend-flatpak
%endif
# Conflicts with plasma5-pk-updates
# Recommends:     %%{name}-notifier
Recommends:     %{name}-backend-fwupd

%description
Discover is a graphical software manager for the KDE Plasma desktop. It helps users to find software they might want easily and quickly.

By allowing to navigate a software library by search, categories, top lists along with detailed application information including screenshots and reviews, users can more quickly find applications that suit their needs.

%package backend-packagekit
Summary:        PackageKit Backend for Discover
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
# Technically libdiscover and not the backend implements AppStream support, but
# it's useless without system package management
Requires:       AppStream
Requires:       PackageKit
Requires:       appstream-provider

%description backend-packagekit
A plugin for Discover to support management of system packages and repositories
using PackageKit.

%package backend-flatpak
Summary:        Flatpak Backend for Discover
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       flatpak

%description backend-flatpak
A plugin for Discover to support installation and management of Flatpak
applications and repositories.

%package backend-fwupd
Summary:        fwupd Backend for Discover
Group:          System/GUI/KDE
Requires:       %{name} = %{version}

%description backend-fwupd
A plugin for Discover to support updates of system firmware using fwupd.

%package notifier
Summary:        Update notifier for KDE Software Manager
Group:          System/GUI/KDE
Conflicts:      plasma5-pk-updates
Obsoletes:      %{name}-plasmoid < %{version}
Requires:       %{name} = %{version}

%description notifier
This is a notifier for Discover to inform the user that updates are available and allows the
user to install them using Discover.

%lang_package

%prep
%autosetup -p1

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %suse_update_desktop_file -r org.kde.discover Qt KDE System PackageManager

  # Even without the snap backend, this is installed...
  rm %{buildroot}%{_kf5_applicationsdir}/org.kde.discover.snap.urlhandler.desktop

%if %{with lang}
  %find_lang libdiscover %{name}.lang
  %find_lang plasma-discover %{name}.lang

  %find_lang plasma-discover-notifier notifier.lang
%else
  touch notifier.lang
%endif

%files
%license COPYING*
%{_kf5_bindir}/plasma-discover
%{_kf5_libdir}/plasma-discover/
%dir %{_kf5_plugindir}/discover/
%{_kf5_plugindir}/discover/kns-backend.so
%{_kf5_applicationsdir}/org.kde.discover.desktop
%{_kf5_applicationsdir}/org.kde.discover.urlhandler.desktop
%{_kf5_iconsdir}/hicolor/*/apps/plasmadiscover.*
%{_kf5_notifydir}/discoverabstractnotifier.notifyrc
%{_kf5_kxmlguidir}/plasmadiscover/
%dir %{_kf5_sharedir}/libdiscover/
%dir %{_kf5_sharedir}/libdiscover/categories/
%{_kf5_appstreamdir}/org.kde.discover.appdata.xml
%{_kf5_sharedir}/discover/
%{_libdir}/libexec/kf5/discover/
%{_kf5_knsrcfilesdir}/discover_ktexteditor_codesnippets_core.knsrc
%{_kf5_debugdir}/discover.categories

%if %{with lang}
%files lang -f %{name}.lang
%endif

%files backend-packagekit
%license COPYING*
%{_kf5_plugindir}/discover/packagekit-backend.so
%{_kf5_sharedir}/libdiscover/categories/packagekit-backend-categories.xml
%{_kf5_appstreamdir}/org.kde.discover.packagekit.appdata.xml

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150100
%files backend-flatpak
%license COPYING*
%{_kf5_plugindir}/discover/flatpak-backend.so
%{_kf5_sharedir}/libdiscover/categories/flatpak-backend-categories.xml
%{_kf5_appstreamdir}/org.kde.discover.flatpak.appdata.xml
%{_kf5_applicationsdir}/org.kde.discover-flatpak.desktop
%{_kf5_iconsdir}/hicolor/*/apps/flatpak-discover.svg
%endif

%files backend-fwupd
%license COPYING*
%{_kf5_plugindir}/discover/fwupd-backend.so

%files notifier -f notifier.lang
%license COPYING*
%dir %{_kf5_plugindir}/discover-notifier
%{_kf5_configdir}/autostart/org.kde.discover.notifier.desktop
%{_libdir}/libexec/DiscoverNotifier
%{_kf5_plugindir}/discover-notifier/DiscoverPackageKitNotifier.so
%{_kf5_plugindir}/discover-notifier/FlatpakNotifier.so
%{_kf5_applicationsdir}/org.kde.discover.notifier.desktop

%changelog
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- Changes since 5.18.4.1:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * flatpak: Don't issue commands when cancelled (kde#404622)
- Drop patches, now upstream:
  * 0001-Make-it-compile-against-qt5.15.-SkipEmptyParts-is-pa.patch
* Mon Apr 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build against Qt 5.15:
  * 0001-Make-it-compile-against-qt5.15.-SkipEmptyParts-is-pa.patch
* Fri Apr 10 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add missing kdeclarative-components runtime dependency (boo#1169153)
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- Changes since 5.18.3:
  * fix toplevels test
  * fwupd: improve error message
  * fwupd: improve cancellable usage
  * flatpak: Don't insist on performing tasks after cancellation (kde#419062)
  * odrs: Remove seemingly unused cache files
  * flatpak: fix crash (kde#419107)
  * cmake: Include messages about availability of Flatpak and Fwupd
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Too many changes to list here
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- Changes since 5.18.1:
  * Properly react to failed transactions
  * packagekit: Fix updatesCountChanged signal emission
  * flatpak: fix build on old flatpak versions
  * flatpak: after performing operations, check for unused refs
  * flatpak: make sure the progress isn't over 100
  * flatpak: provide the arch when checking the timestamp
  * flatpak: reduce leakage of GObjects
- Enable KUserFeedback support
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- Changes since 5.18.0:
  * pk: make sure we get the local package details
  * Simplify UI logic
  * Fix typo
  * pk: list codecs as addons
  * Don't offer to show more when there's not more to show (kde#417290)
  * remove warning when there's no kuserfeedback
  * snap: mark transactions as cancelled when we cancel them
  * Don't escape search text in search page title (kde#416781)
  * Use real Kirigami Separators instead of blue rectangles
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- Changes since 5.17.90:
  * Only show app's release date and omit the time of day (which is never set anyway)
  * Telemetry is disabled by default
  * appstream: improve screenshots display
  * packagekit: fix opening files on archlinux
  * packagekit: don't show where the package will be installed (kde#400044)
  * fix build for older Qt to 5.14.0
  * forgot file
  * appstream: support appstream uri alt ids (kde#416283)
  * utils: prefer using stl than custom functions
  * feedback: fix opening the plasma feedback configure dialog (kde#416349)
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Too many changes to list here
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- Changes since 5.17.3:
  * fwupd: don't whine when we have unsupported hardware
  * --verbosity
  * sources: for some reason, QML didn't find the toolTip role anymore on my Neon system
  * pk: only trigger offline updates after a successful download (kde#413028)
  * Account for padding in the height of the screenshot popup (kde#413629)
  * Account for weirdly horizontal screenshots
  * progressview: don't highlight the current index of the view (kde#414455)
  * Don't include newlines in searches (kde#414530)
  * pk: improve behaviour when dealing with local files
  * pk: cache appstream component names
  * don't overwrite mainItem (kde#414145)
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- Changes since 5.17.2:
  * flatpak: --verbosity
  * ui: fix updates page
  * flatpak: show an error message when remotes are faulty
  * pk+suse: include a hack to allow apps to be executed (kde#412986)
  * pk: fix fallback invocation plan
  * ui: improve busy indicator handling (kde#412908)
  * kns: don't read globals when loading KNS files
  * flatpak: save quite some unnecessary QString allocations at startup
  * app page: fix display of faulty screenshots (kde#413812)
  * --qml warnings
  * --warnings
  * kns: fetching details might increase the description we have
  * --qclp runtime warnings
  * ui: remove LinkLabel
  * Fix qml warnings
  * Address qml tests
  * dummy: fix test
  * Help cmake find the tests
  * flatpak: make test more resilient
  * flatpak: downloading flathub metadata takes a while
  * flatpak: remove duplicated code
  * kns: fix test
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- Changes since 5.17.1:
  * notifier: make it possible to replace the instance
  * app delegate: improve on narrow windows (kde#411828)
  * flatpak: oops
  * pk: notify about problems regarding file listing
  * appstream: support more formats of appstream urls (kde#408419)
  * notifier: don't autostart outside of Plasma (kde#413235)
  * snap: fix cancelling (kde#404358)
  * pk: readability
  * pk: Make action buttons translatable
  * notifier: Make action buttons translatable
  * pk: don't show redundant packages on updates
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- Changes since 5.17.0:
  * Revert change to make the notification persistent
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- Changes since 5.16.90:
  * updates: improve cancellability calculation (kde#407466)
  * pk: Still need to refresh the database at start
  * AppPage: Give some space to render screenshot busy indicators (kde#409504)
  * Use the right API for retrieving SPDX licences (kde#408112)
  * packagekit: Improve update UI population (kde#412035)
  * Fix qml warning
  * Make sure the installed page is properly sorted by default (kde#412653)
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Too many changes to list here
- Recommend the fwupd backend by default again
- Drop conditions for Leap 42
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- Changes since 5.16.4:
  * odrs: fix fetching reviews (kde#411034)
  * odrs: don't leak qnam instances
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- Changes since 5.16.3:
  * notifier: don't accumulate notifications
  * notifier: Use QPointer instead of a raw pointer for notifications
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- Changes since 5.16.2:
  * snap: fix typo
  * snap: match gnome software in the id used when there's no appstream id
  * i18n: use rc.cpp for extra sources
  * Fix XML
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- Changes since 5.16.1:
  * make appstream files validate
  * odrs: delay QNAM initialization
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- Changes since 5.16.0:
  * flatpak: Indicate that updates are being fetched (kde#408608)
  * --verbose
  * kns (mostly): Don't show weird padding if the thumbnails are too small (kde#408109)
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- Changes since 5.15.90:
  * Make sure "Window Decorations" shows up in "Plasma Addons" The Aurorae ones are already there; let's move this one there too (kde#408110)
  * notifier: Also open discover when the plasmoid is expanded
  * Use onClicked for Home button (kde#407636)
  * Get PaginateModel class ready for frameworks
  * notifier: delay fetching updates a few seconds
  * Put "Splash Screens" in the "Plasma Addons" category BUG: 407692 FIXED-IN: 5.16.0 (kde#407692)
  * fwupd: allow updates that need a reboot to go through as well
  * fwupd: fix downloading updates
  * Re-add zero bottom padding, which was removed by mistake
  * snap: Use AppStreamIntegration for snap reviews as well
  * snap & packagekit: Refresh ratings when they arrive (kde#407471)
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Too many changes to list here
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- Changes since 5.15.4:
  * flatpak: Improve matching of remotes
  * flatpak: remove unnecessary complexity
  * flatpak: make sure we don't consider appstream fetched too early (kde#406923)
  * Update copyright year
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- Changes since 5.15.3:
  * Ignore source packages when adding them to the PK list
  * flatpak: disable dis/enabling sources (kde#404370)
  * fwupd: No need to make the code hard to read for no reason
  * Sources: Fix QML error when un/selecting a source
  * kns: wallpaperplugin.knsrc comes from plasma
  * Fix warning, don't catch object we don't need
  * Don't accept invalid KNS EntryInternal results
  * Fix --categories with delayed categories
  * Restore proper background color on list and sources pages
  * Don't allow refreshing during updates (kde#403333)
  * Use Attica forwarding headers
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- Changes since 5.15.2:
  * Don't crash if the fwupd error is null
  * flatpak: Fix look-up of updates on flatpak (kde#404434)
  * flatpak: fix warning
  * flatpak: Report errors when running a transaction (kde#404913)
  * Set the sources label to  textFormat: Text.StyledText (kde#404755)
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- Changes since 5.15.1:
  * Provide a better package icon
  * Mark all radio buttons as such (kde#404400)
  * Make sure we connect the action to its bridge (kde#403378)
  * Remove connectivity flash at start (kde#404610)
  * [Updates page] Try our best to not elide version strings (kde#404624)
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- Changes since 5.15.0:
  * ApplicationPage: Fix crash when the sources model gets refreshed (kde#404402)
  * fwupd: warn if threads could not be killed
  * UpdatesPage: Fix icon sizing on small screens (kde#404070)
  * Set parent on newly created fwupd resource (kde#402328)
  * Don't show tooltip when search field has text and set a timeout period
  * Add a timeout for KNS backends (kde#399981)
  * Don't enable the install button in the app page until we know the state
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * [Updates page] Use a more universally-available arrow character (kde#403544)
  * Search-enable the application page
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Too many changes to list here
* Sun Jan 13 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Don't recommend the fwupd backend for now
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Don't enable the install button in the app page until we know the state
  * fwupd: simplify logic that initialises files to download
  * fwupd: fix leak on faulty devices
  * Don't inspect sources if the backend isn't confident about offering good results (kde#401844)
  * ux: Make sure we can reach the view from the appdelegate
  * pk: Don't show the dependencies button if there aren't dependencies (kde#400781)
  * snap: show more useful information for each channel (kde#401907)
  * Don't show a hover event if there's nothing to open (kde#401833)
  * Don't automatically refresh if the user already asked apt to do so (kde#401810)
  * Source enabled checkbox value shouldn't change only because it was clicked (kde#401663)
  * fwupd: Don't get releases for unsupported devices
  * fwupd: be more verbose when returning a faulty checksum because a file can't be read
  * fwupd: remove unused declaration
* Sat Jan  5 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Move flatpak-discover icon to the backend-flatpak subpackage
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * kns: fix crash upon removing a category (kde#401435)
  * Don't use an icon that is only supposed for plasmoids
  * flatpak: Always connect to finished before running
  * Remove unused function
  * Fix global progress display for updates (kde#400891)
  * Avoid potential race condtion with QFutureWatcher in FWUPD backend
  * flatpak: remove duplicated line
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- Changes since 5.14.2:
  * snap: improve transaction status (kde#396351)
  * Use the locale to create the release date string (kde#400314)
  * pk: readability
  * flatpak: use the path to identify a local remote
  * flatpak: fix freeze (kde#400212)
  * flatpak: use pkgconfig targets instead of using variables
  * flatpak: fix warning
  * fwupd: improve fwupd lookup
  * fwupd: Cancel job upon close
  * fwupd: don't report passive errors about unsupported devices
  * fwupd: fix error handling logic
  * fwupd: --output
  * fwupd: no need to pass a pointer reference to read errors
  * fwupd: don't ignore fwupd_client_get_devices errors
  * fwupd: don't ignore get releases errors
  * fwupd: silence invalid file errors (kde#400181)
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- Too many changes to list here
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- Too many changes to list here
- Refresh 0001-Warning-for-FlatHub.patch
* Tue Oct  9 2018 fabian@ritter-vogt.de
- Split available backends into subpackages
- Improve description by using the one from Debian and rewording it
  slightly.
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Too many changes to list here
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Sat Sep 15 2018 Wolfgang Bauer <wbauer@tmo.at>
- Build without fwupd on Leap 42
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Too many changes to list here
- Enable fwupd backend
- Use %%license
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * Don't try to trigger an empty transaction (kde#397759)
  * PK: wait until we have fetched the packages that dont' come from appstream (kde#397192)
  * Fix navigation after search (kde#391931)
  * Remove wrong assert
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * KNS: Fix leak of resource ratings
  * When sorting by release date, show newer first
  * Prevent crash (kde#396564)
  * Readability
  * Fix CMakeLists.txt to work with older versions of CMake
  * KNS: Don't offer the backends to add if we know they're broken
  * FeaturedModel: Make sure the file is written before we read
  * Fix featured json file warning
  * Fix warning
  * Silence false positive warning on --mode
  * Fix display if there's no source description
  * Proper status when removing snaps (kde#396351)
  * Properly check for pkqt
  * Use consistent spacing in the missing backends footer
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * PK: Make sure we resolve the transaction application if it fails (kde#395994)
  * KNS: don't start searches before initializing (kde#395966)
  * Report a progressing change when we finish to set up and there's nothing pending
  * Recheck fetching after we remove a backend
  * flatpak: don't crash if we get null updates (kde#394713)
  * Don't set property twice
  * Trigger a refresh when appstream data isn't available when on aptcc
  * Don't catch unneeded value in lambda
  * Fix warning: use the right API to get the component desktop id
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * Simplify flatpak initialization process
  * Include the donation URL from KNS
  * When installing a resource with several payloads, fetch all of them (kde#395720)
  * Improve how progress is processed when installing one application (kde#391058)
  * PK: Don't show an error message when simulating
  * fix warnings
  * Fix crash (kde#395676)
  * Properly remove the items from the FeaturedModel
  * Flatpak: Make sure we release every time we aquire (kde#394558)
  * Fix there being more security updates than total updates in notifier (kde#392056)
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * ASAN: Specify buffer size
  * ASAN: Fix possible division by 0
  * Fix warning, add missing interface
  * Fix build with newer flatpak
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Too many changes to list here
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Too many changes to list here
- Refresh 0001-Warning-for-FlatHub.patch
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * Improve display of Progress element (kde#393323)
  * More elegant syntax for qrc files in cmake
  * Make sure we update the checkability of all delegates when one changes
  * PK: Improve information on resources that extend others
  * Report 0%% update progress when not progressing
  * Infer cancellability of the StandardBackendUpdater (kde#390319)
  * Forward action enabled state into the button
  * Don't change the resources while updating (kde#391262)
  * Remove unused variable
  * Fix typo
  * Fix notifier button placement
  * Fix warning on Qt 5.11
  * Remove wrongly commented code
  * Report when root categories change
  * Readability
  * Properly concatenate strings
  * Fix crash when installing flatpak files
  * Remove unneeded dependency
  * Don't crash when cancelling flatpak jobs (kde#391941)
  * Remove unused imports
  * --debug
  * Make sure we don't crash automatically (kde#392082)
  * Fix sorting when the actual comparison matches
  * Fix warning in Qt 5.11
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * Simplify the tasks view (kde#391760)
  * Remove unneeded includes
  * Fix dbus path
  * Include a test for cancelling flatpak installations
  * Improve status of FlatpakTransaction
  * Remove pointless i18n call
  * KNS: Only indicate that it's fetching if already fetching reviews
  * Include a test that makes sure we can list origins
  * Solve some inconsistencies found when testing flatpak
  * Introduce a flatpak test
  * No need to pass the extra arguments on the Update Action (kde#391801)
  * Add Qt5::Xml
  * Simplify KNSTransaction creation (kde#390236)
  * Fix test
  * Add a test to make sure we don't add resources with the wrong URL
  * kns: Fix logic for adding screenshots (kde#391190)
  * Add debug information when the searched URI is wrong
* Fri Mar 23 2018 fabian@ritter-vogt.de
- Add patch to show an informative warning when adding FlatHub:
  * 0001-Warning-for-FlatHub.patch
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Too many changes to list here
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * Fix checking if the package is already on the ResProxyModel
  * Add multimedia sub-categories
  * Put all systemwide add-ons in Plasma Addons category (kde#390594)
  * Sort by sortable rating
  * Make it possible to debug sorting
  * Make sure sortableRating is initialised
  * Don't let the user write the first review for apps they haven't installed
  * Fix warning
  * Only instantiate the ProgressView sheet when it's to be displayed
  * Fix placement of the BusyIndicator over loading screenshots (kde#390391)
  * Update copyright year (kde#390358)
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Update copyright year (kde#390358)
  * Notify about the backend (kde#390339)
  * Don't notify when the number of updates becomes smaller (kde#390322)
  * Remove commented out code
  * Forgot to add file
  * Fix freeze when showing the ApplicationPage (kde#390123)
  * Only report changes when they actually happen
  * Fix binding loop when showing the update description
  * Disable Review button for resources that aren't installed (kde#390053)
  * Show a beautiful disabled icon for updates (kde#390076)
  * Make sure we mark as busy before clearling the list (kde#390114)
  * Add some paddings to the Review button (kde#390030)
  * Make it possible to specify a fallback appstream id (kde#390016)
  * Use the default passive notification amount (kde#388087)
  * Remove redundant action (kde#389767)
  * Fix tests, now we don't show a list from a URL
  * Only show the description for PackageKit sources (kde#389715)
  * Print a warning when a remote can't be removed
  * Fix dummy build
  * Address source by id look-up in Flatpak source
  * Fix source removal
  * Make it possible for the source id to be different from the display string
  * Fix warnings
  * Reduce duplication in flatpak sources display
  * Flatpak: don't show full url, just the hostname (kde#389714)
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Too many changes to list here
* Wed Jan 24 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, gcc6 no longer works because of a
  change to the default compiler flags in openSUSE:Leap:42.3:Update
  (boo#1077345)
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Too many changes to list here
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * Keep track of the kns entries status internally
  * Revert "Make sure m_isFetching is initialized when we use it"
  * Make sure m_isFetching is initialized when we use it
  * Make it possible to navigate screenshots from the overlay (kde#387402)
  * Hide reviews page when opening the review dialog (kde#386902)
  * Revert "Improve error message when review dialog contents are wrong"
  * Improve error message when review dialog contents are wrong (kde#387261)
  * Usually applications won't be compulsory for a desktop
  * Don't show packages tightly coupled to other desktops by default
  * Readability
  * PK: Use the stream to store the information rather than the transaction (kde#386992)
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * Flatpak: Make sure we don't degrade resources' state
  * If it's busy, try again in a second
  * Group updater refreshes
  * StandardUpdater: Only refresh when it's going to make a difference
  * Narrow down the scope of a variable
  * Make it possible for updaters to show notifications at any time
  * Remove unused code
  * Remove hidden styling from the delegate's comment (kde#387221)
  * No need to explicitly notify
  * Make sure we remove the Transaction before it's destroyed
  * Revert "Install related ref instead attempting to upgrade it"
  * Install related ref instead attempting to upgrade it
  * Link to a url that still exists
  * Don't fetch updates while the updater is working
  * Remove weirdly long timer to display notifications (kde#381812)
  * Simplify notifier logic
  * Don't crash if we get into a weird state (kde#385637)
  * Remove unneeded declaration
  * Make sure we never search on an invalid KNS backend
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * Don't refresh invalid backends (kde#386045)
  * Remove unused class
  * Don't delete resources whenever asked to clear the view
  * Extend the resetModel until the model is ready to be fetched again
  * Make sure we set the page size
  * Unneeded dependency in the library
  * Fix warning
  * Remove unused code
  * --warning: don't capture unused variable
  * Properly listen to ODRS replies
  * Assert on ODRS reviews fetched
  * Don't leak QNetworkAccessManager instances
  * Recover the right delegate background color
  * Improve global updates progress reporting
  * Improve progress reporting in some PackageKit updates
  * Show errors from refreshing (kde#386244)
  * Include the progress of transactions (kde#384038)
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * Include the progress of transactions (kde#384038)
  * Fix adding remote sources
  * list items should be lighter than normal background
  * Use QQC2.Popup instead of Kirigami.OverlaySheet for screenshots (kde#385115)
  * Don't open a null application from the progress view (update transaction)
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * Fix under Qt 5.10
  * Fix tests
  * Remove our isCompact concept and use Kirigami's
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * Use the right update icon when there's no updates
  * When the delegate is compact, don't show the longDescription at all
  * Fix featured filtering
  * Fix listing several sources in an application
  * Fix warnings
  * Optimize adding resources to the model (kde#383743)
  * make for better debug output
  * Don't go through categories more than necessary
  * Properly traverse a hash with iterators
  * Use flatpak_installation_list_installed_refs for listing installed flatpaks
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Too many changes to list here
* Mon Aug 28 2017 fabian@ritter-vogt.de
- Adjust License tag
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * auto generate desktop file for url handling
  * Revert "auto generate desktop file for url handling"
  * auto generate desktop file for url handling
  * Remove the navigationEnabled concept (kde#383294)
  * Fix license, comply with our naming scheme
  * Don't disable the updates action when there are no updates (kde#383294)
  * Some elements aren't reporting a big preview
  * Fallback to the package icon if there isn't a stock icon as well
  * Prevent memory leak
  * Make sure we don't crash when opening flatpakrepo files
  * Make it possible to prevent some resources from being Reviewed
  * Don't show the version if there's none on the ApplicationPage (kde#383036)
  * Make sure we don't render HTML on the Discover page header
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * Fix launching of resources for PackageKit and Flatpak
  * Make the flatpak backend more flexible to issues
  * KNS: Don't connect the stream until the search is in place
  * Improve logic for fetching installed
  * Don't continue fetching when looking for installed resources
  * Stop keeping track of the remaining time (kde#381979)
  * Don't search on KNS when in a category the backend doesn't belong to
  * Slightly cleaner code
  * Make sure the osName isn't "quoted"
  * Allow opening links in the update changelog (kde#381768)
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * Simplify KNSBackend fetch logic (kde#380138)
  * Ignore updates for which we didn't get latest commit
  * Improvements in installation or updates for flatpak backend
  * Flatpak backend: display a popup with error when update or installation fails
  * Avoid starting update transactions twice
  * Remove unused code
  * Make sure changelogs are displayed properly (kde#381248)
  * Fix crash when using Discover during updates (kde#370906)
* Mon Jun 26 2017 fabian@ritter-vogt.de
- Switch to more generic appstream-provider and PackageKit requires
* Sun Jun 25 2017 fabian@ritter-vogt.de
- Add packagekit runtime requirement (boo#1045483)
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * Don't compare a bool to an enum
  * Fix warning
  * Also show a header when doing a global search
  * Fix typos on warnings
  * Agilize search
  * Don't read a file to put it in a temporary file again
  * Fix test
  * Fix typo
  * Populate the actionsMenu right in the SourcesPage
  * Split qml and image qrc files
  * Improve hiding of scrolling controls in the UpdatesPage (kde#380993)
  * Better integrate smaller ApplicationDelegate
  * Don't mark used as unused
  * Fix snap backend build
  * Hopefully fix build in build.ko
  * Include missing margins in the UpdatesPage header controls (kde#380992)
  * Improve apt-config integration in pknotifier
  * Integrate apt setting for periodicity in the notifier (kde#337752)
  * Remove unneeded fwd declaration
  * Centralize reload actions into a generic one that will call the backends
  * Readability
  * Also check the provider like we do in the knshandler
  * Remove unused declaration
  * Make the PackageKit backend more resistant to crashes in PackageKit (kde#376538)
  * Include a header for the settings page for better consistency
  * Don't leak QNAM factories
  * Make sure the status is initialized before using it
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * fix typo
  * Qt 5.7 is needed, make it explicit when searching for Qt
  * Change look of the close description button
  * Rename the generic snap library to DiscoverSnapClient (kde#380356)
  * Don't elide the name, always elide the category label (kde#378351)
  * Improve how we initialize json objects
  * Make the tasks page a global overlay rather than just over the pages (kde#378566)
  * Remove unused file
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * Share odrs reviews instance between flatpak and packagekit
  * fix compile
  * Fix duplicate Discover entry on the Application Menu (kde#379784)
  * Update required KF5 and Kirigami dependencies
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Too many changes to list here
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * Don't make the size of the icon match the size of the text (kde#378570)
  * Make sure categories are populated
  * Make sure QSharedPointer is included
  * Prefer override
  * Remove unneeded include
  * Fix tests
  * Fix license on the appdata file
  * Fix crash
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * Simplify the ReviewDelegate
  * Fix initialization of the ApplicationPage
  * Adapt to API changes in Kirigami 2.0
  * Use correct reference to the review model
  * Minor improvements to review delegate
  * Define variable
  * Make sure we don't call cleaned up streams (kde#376162)
  * Fix enabling/disabling sources (kde#377327)
  * Account for requestComments sometimes returning a nullptr (kde#377314)
  * Fix source removal
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Fix how we deal with margins in the ApplicationDelegate
  * Don't stretch icons
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * Make sure we don't show warnings unless it's absolutely necessary
  * Make sure the Remove button doesn't overlap the text
  * Improve local packages display on local packages
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * Don't show the version if there's no version to show
  * Don't sort resources if the delivery is sorted
  * KNS: Improve how we react to error messages
  * Use the right name for the method
  * Also show passive errors on the console
  * Simplify code
  * Also expose YaST repository configuration if present
  * Fix arguments when running .desktop files with runservice
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * Add missing overrides
  * Make sure we don't always search to kns
  * Only notify changes when they actually change
  * Don't emit null resources
  * Don't show unexisting local packages as if local
  * Fix the SettingsPage
  * libdiscover: Remove superfluous semicolon
  * Lambda not needed anymore
  * Fix signal type, don't emit as a reference
  * Restore discover-exporter
  * Gain control over the applications shown on the main browsing page
  * Include an IconName on the notifyrc file
  * Properly process Discover positional arguments
  * associate with deb and rpm to expose local file install capability
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * See https://www.kde.org/announcements/plasma-5.8.5-5.8.95-changelog.php#discover
- Remove patches, now upstream:
  * 0001-Fix-arguments-when-running-.desktop-files-with-runse.patch
  * 0002-Also-expose-YaST-repository-configuration-if-present.patch
- Update BuildRequires:
  * Uses kirigami2 now
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
- Add patches for openSUSE integration:
  * 0001-Fix-arguments-when-running-.desktop-files-with-runse.patch
  * 0002-Also-expose-YaST-repository-configuration-if-present.patch
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
- Remove upstream patches:
  * 0001-Make-screenshots-visible-when-only-one.patch
* Wed Nov  2 2016 alarrosa@suse.com
- Added 0001-Make-screenshots-visible-when-only-one.patch which fixes
  an issue by which discover didn't show application screenshots when
  there was only one screenshot (kde#371724)
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
- Removed patches (now upstream):
    0001-Fix-build-with-older-Qt.patch
    0003-Drop-usage-of-templates-from-LinkButton.patch
    0004-Remove-unused-component.patch
    0002-Don-t-artificially-require-QtQuick-5.7.patch
* Mon Sep 26 2016 fabian@ritter-vogt.de
- Bump kirigami(-devel) requirement to 1.1.0 (kde#369323)
- Drop libqt5-qtquickcontrols2 requirement (fixed upstream)
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
- Added patches:
    0001-Fix-build-with-older-Qt.patch
    0002-Don-t-artificially-require-QtQuick-5.7.patch
    0003-Drop-usage-of-templates-from-LinkButton.patch
    0004-Remove-unused-component.patch
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
- Drop upstreamed fix_for_gcc4.diff
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Thu Mar 10 2016 tittiatcoke@gmail.com
- Recommend the lang package when the languages are packaged
  (boo#970470)
* Fri Feb  5 2016 tittiatcoke@gmail.com
- KDE Software Manager based on AppStream data (appdata)
  * Initial version 5.5.4
